SupabaseExtensions extension

on
  • SupabaseClient

Properties

isLogged bool

Available on SupabaseClient, provided by the SupabaseExtensions extension

Returns if user has logged in or not
no setter
jwt String?

Available on SupabaseClient, provided by the SupabaseExtensions extension

Return jwt (accessToken) of current session
no setter
supabaseKey String

Available on SupabaseClient, provided by the SupabaseExtensions extension

no setter
supabaseRestUrl String

Available on SupabaseClient, provided by the SupabaseExtensions extension

no setter
uid String?

Available on SupabaseClient, provided by the SupabaseExtensions extension

Returns current user id (user has logged in )
no setter

Methods

closeAllStreams() Future<void>

Available on SupabaseClient, provided by the SupabaseExtensions extension

Closes all the open stream done with listening to table changes
on(String table, CrudEvent? eventType) Stream

Available on SupabaseClient, provided by the SupabaseExtensions extension

Returns a stream that listen to changes when eventType occurred in table
onDelete(String table) Stream

Available on SupabaseClient, provided by the SupabaseExtensions extension

Returns a stream that listen to changes when 'DELETE' occurred in table
onInsert(String table) Stream

Available on SupabaseClient, provided by the SupabaseExtensions extension

Returns a stream that listen to changes when 'INSERT' occurred in table
onUpdate(String table) Stream

Available on SupabaseClient, provided by the SupabaseExtensions extension

Returns a stream that listen to changes when 'UPDATE' occurred in table
sql(String rawSql) Future<QueryResults>

Available on SupabaseClient, provided by the SupabaseExtensions extension

Executing a given rawSql string statement and returns the rows